@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import print_function, unicode_literals
+
 __description__ = 'OpenPGP key exchange for humans'
 __long_description__ = """
 monkeysign is a tool to overhaul the OpenPGP keysigning experience and
@@ -46,6 +48,12 @@ __license__ = """
 
 __website__ = 'http://web.monkeysphere.info/monkeysign'
 __documentation__ = 'http://monkeysign.readthedocs.io/en/' + __version__
+# hack to include the credits in the documentation
+# maybe this should be parsed from a AUTHORS file instead, see
+# https://0xacab.org/monkeysphere/monkeysign/issues/56
+# if you feel comptent to respond to Code of Conduct reports,
+# make sure you add your email address below
+# credits-start
 __authors__ = ['In alphabetical order:',
                '',
                'Antoine Beaupré',
@@ -55,6 +63,7 @@ __authors__ = ['In alphabetical order:',
                'Kristian Fiskerstrand',
                'Philip Jägenstedt',
                'Ramakrishnan Muthukrishnan',
+               'Simon Fondrie-Teitler',
                'Tobias Mueller',
                ]
 __documenters__ = ['In alphabetical order:',
