@@ -619,7 +619,7 @@ class TempKeyring(Keyring):
         Keyring.__init__(self, tempfile.mkdtemp(prefix="pygpg-"))
 
     def __del__(self):
-        shutil.rmtree(self.homedir)
+        shutil.rmtree(self.homedir, ignore_errors=True)
 
 class OpenPGPkey():
     """An OpenPGP key.
