@@ -361,6 +361,8 @@ class MonkeysignScan(gtk.Window):
         self.qrcodewidget.pack_start(label, False)
         self.qrcodewidget.pack_start(swin)
 
+        self.qrcodewidget.connect("event", self.qr_code_event)
+
     def create_secret_keys_display(self):
         """list the secret keys for selection somewhere"""
         i = 0
@@ -695,7 +697,7 @@ class MonkeysignScan(gtk.Window):
     def process_scan(self, data):
         """process zbar-scanned data"""
 
-        self.msui.log(_('zbar captured a frame, looking for 40 character hexadecimal fingerprint'))
+        self.msui.log(_('zbar captured a frame, looking for 40 character hexadecimal fingerprint in %s') % data)
         m = re.search("((?:[0-9A-F]{4}\s*){10})", data, re.IGNORECASE)
 
         if m is not None:
@@ -789,3 +791,22 @@ class MonkeysignScan(gtk.Window):
 
     def documentation_dialog(self, widget, data=None):
         webbrowser.open(monkeysign.__documentation__, autoraise=True)
+
+    def qr_code_event(self, thing, event):
+        if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
+            self.qr_code_right_click_menu(event)
+
+    def qr_code_right_click_menu(self, event):
+        menu = gtk.Menu()
+        menu_items = [
+            (_('_Save QR code as...'), self.save_qrcode),
+            (_('_Print QR code...'), self.print_op),
+        ]
+
+        for item in menu_items:
+            new_menu_item = gtk.MenuItem(item[0])
+            new_menu_item.connect('activate', item[1])
+            new_menu_item.show()
+            menu.append(new_menu_item)
+
+        menu.popup(None, None, None, event.button, event.time)
