@@ -238,6 +238,8 @@ class BaseTestCase(unittest.TestCase):
         self.args = [ '--no-mail' ] + self.args + [ x for x in sys.argv[1:] if x.startswith('-') ]
         if self.pattern is not None:
             self.args += [ self.pattern ]
+        # do not read system-wide configs in tests
+        MonkeysignArgumentParser.configs = []
         self.ui = MonkeysignUi(self.args)
         self.ui.keyring = TempKeyring()
         self.ui.prepare() # needed because we changed the base keyring
@@ -288,6 +290,14 @@ this duplicates tests from the gpg code, but is necessary to test later function
         self.ui.sign_key()
         self.assertGreaterEqual(len(self.ui.signed_keys), 1)
 
+    def test_sign_own_key(self):
+        """Test that signing a user's own key fails"""
+        self.ui.pattern = '96F47C6A'
+        self.test_copy_secrets()
+        self.ui.sign_key()
+        self.assertEquals(len(self.ui.signed_keys), 0)
+        self.ui.pattern = '7B75921E'
+
     def test_gpg_conf(self):
         """test if gpg.conf default-key works"""
         # this fails with GnuPG 2.1
