@@ -157,13 +157,12 @@ class MonkeysignArgumentParser(argparse.ArgumentParser):
                                    'passed on the commandline in the "%%(to)s"'
                                    ' field, or the command must parse the '
                                    '"To:" header (default: %(default)s)'))
-        default_mua = "xdg-email --utf8 --to '%%(to)s' --subject '%%(subject)s' --body '%%(body)s' --attach '%%(attach)s'"
+        default_mua = "xdg-email --utf8 --to '%(to)s' --subject '%(subject)s' --body '%(body)s' --attach '%(attach)s'"
         self.add_argument('--mua', nargs='?', default=None, const=default_mua,
-                            help=_('Mail User Agent to use to send mail. all '
-                                   'parameters are passed on the commandline,'
-                                   'overrides --mta. '
-                                   '(default: %s when specified)')
-                            % default_mua)
+                          help=_('Mail User Agent to use to send mail. all '
+                                 'parameters are passed on the commandline,'
+                                 'overrides --mta. '
+                                 '(default: %(const)s when specified)'))
         self.add_argument('--nomail', '--no-mail', action='store_true',
                             help=_('do not send email at all'))
         self.add_argument('-t', '--to',
